@@ -5,7 +5,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 binmode(STDOUT, ":encoding(UTF-8)");
 
@@ -509,6 +509,11 @@ sub add
     my $self = shift;
     my @args = @_;
 
+    if (scalar @args == 1 && $args[0] eq '-')
+    {
+        @args = _read_lines_from_stdin();
+    }
+
     if (! @args)
     {
         print "Need to provide articles names to add\n";
@@ -556,6 +561,20 @@ sub add
     return @article_ids;
 }
 
+sub _read_lines_from_stdin
+{
+    # Return an list of arguments by reading lines from STDIN
+
+    my @args;
+    while (<STDIN>)
+    {
+        $_ =~ s/^\s+|\s+$//g ; # remove leading and trailing whitespace
+        next if ($_ eq '');    # ignore blank lines
+        push(@args, $_);
+    }
+    return @args;
+}
+
 
 sub show
 {
@@ -744,8 +763,9 @@ sub help
   $ zapzi config set KEY VALUE
     Set configuration variable KEY to VALUE.
 
-  $ zapzi add [-t TRANSFORMER] FILE | URL | POD
+  $ zapzi add [-t TRANSFORMER] FILE | URL | POD | -
     Adds article to database. Accepts multiple file names or URLs.
+    or read articles names from standard input with -
     TRANSFORMER determines how to extract the text from the article
     and can be HTML, HTMLExtractMain, POD or TextMarkdown
     If not specified, Zapzi will choose the best option based on the
@@ -816,7 +836,7 @@ App::Zapzi - store articles and publish them to read later
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 DESCRIPTION
 
@@ -982,7 +1002,7 @@ Rupert Lane <rupert@rupert-lane.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Rupert Lane.
+This software is copyright (c) 2015 by Rupert Lane.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
