@@ -6,7 +6,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 use Moo;
 use SQL::Translator;
@@ -91,7 +91,7 @@ sub init
     my @articles = ({title => 'Welcome to Zapzi', folder => 100,
                      article_text =>
                          { text => '<p>Welcome to Zapzi! Please run <pre>zapzi -h</pre> to see documentation.</p>'}});
-    $self->schema->populate('Article', \@articles);
+    scalar $self->schema->populate('Article', \@articles);
 
     my @config = ({name => 'schema_version',
                    value => $self->schema->schema_version} );
@@ -165,7 +165,7 @@ App::Zapzi::Database - database access for Zapzi
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 DESCRIPTION
 
@@ -214,7 +214,7 @@ Rupert Lane <rupert@rupert-lane.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Rupert Lane.
+This software is copyright (c) 2015 by Rupert Lane.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
