@@ -6,7 +6,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 use Carp;
 use Data::Validate::URI 0.06;
@@ -77,7 +77,11 @@ sub _http_request_headers
     no strict 'vars'; ## no critic - $VERSION does not exist in dev
     $ua .= "/$VERSION" if defined $VERSION;
 
-    return {headers => {'User-agent' => $ua}};
+    return {headers => {
+                           'User-agent' => $ua,
+                           # Don't gzip encode the response
+                           'Accept-encoding' => 'identity'
+                       }};
 }
 
 1;
@@ -94,7 +98,7 @@ App::Zapzi::Fetchers::URL - fetch article via URL
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 DESCRIPTION
 
@@ -120,7 +124,7 @@ Rupert Lane <rupert@rupert-lane.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Rupert Lane.
+This software is copyright (c) 2015 by Rupert Lane.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
